set __system(mkdir) "mkdir"
set __system(rm) "rm"
set __system(browser) "netscape"
set __system(mv) "mv"
set __system(tclsh) "tclsh7.4"
set __system(cp) "cp"
set __system(mail) ""
set __system(language) "english"
set __system(languages) {english japanese}
